aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorpaweldomas <pawel.domas@jitsi.org>2016-05-19 14:20:30 +0200
committerpaweldomas <pawel.domas@jitsi.org>2016-05-19 14:20:30 +0200
commit3a3bf3158265bf1f8d06d7b30e8a143d499d6a72 (patch)
treef9de5f01790fd725440d6c5ea3b8996f65ac9211 /src
parent24297d644f5cda26393d0379b6ecd2801a40a198 (diff)
downloadjitsi-3a3bf3158265bf1f8d06d7b30e8a143d499d6a72.zip
jitsi-3a3bf3158265bf1f8d06d7b30e8a143d499d6a72.tar.gz
jitsi-3a3bf3158265bf1f8d06d7b30e8a143d499d6a72.tar.bz2
Rename Jibri "error" status to "failed"
Diffstat (limited to 'src')
-rw-r--r--src/net/java/sip/communicator/impl/protocol/jabber/extensions/jibri/JibriIq.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/jibri/JibriIq.java b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/jibri/JibriIq.java
index c49774b..53c5c3f 100644
--- a/src/net/java/sip/communicator/impl/protocol/jabber/extensions/jibri/JibriIq.java
+++ b/src/net/java/sip/communicator/impl/protocol/jabber/extensions/jibri/JibriIq.java
@@ -83,7 +83,7 @@ public class JibriIq
private Action action = Action.UNDEFINED;
/**
* XMPPError stores error details for {@link Status#ERROR}.
*/
private XMPPError error;
@@ -239,7 +239,7 @@ public class JibriIq
/**
* Sets the <tt>XMPPError</tt> which will provide details about Jibri
* failure. It is expected to be set when this IQ's status value is
- * {@link Status#ERROR}.
+ * {@link Status#FAILED}.
*
* @param error <tt>XMPPError</tt> to be set on this <tt>JibriIq</tt>
* instance.
@@ -251,7 +251,7 @@ public class JibriIq
/**
* Returns {@link XMPPError} with Jibri error details when the status is
- * {@link Status#ERROR}.
+ * {@link Status#FAILED}.
*/
public XMPPError getError()
{
@@ -341,7 +341,7 @@ public class JibriIq
/**
* An error occurred any point during startup, recording or shutdown.
*/
- ERROR("error"),
+ FAILED("failed"),
/**
* There are Jibri instances connected to the system, but all of them
@@ -83,7 +83,7 @@ public class JibriIq
private Action action = Action.UNDEFINED;
/**
- * XMPPError stores error details for {@link Status#ERROR}.
+ * XMPPError stores error details for {@link Status#FAILED}.
*/
private XMPPError error;